Model Constructors
================================

This module provides constructors for building concept-based models from specifications.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Constructor Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   BipartiteModel
   GraphModel


Class Documentation
----------------------

.. autoclass:: BipartiteModel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: GraphModel
   :members:
   :undoc-members:
   :show-inheritance:
